@@ -1,5 +1,6 @@
 """CLI (Command Line Interface) of OE Python Template."""
 
+import os
 from enum import StrEnum
 from typing import Annotated
 
@@ -8,12 +9,24 @@ import uvicorn
 import yaml
 from rich.console import Console
 
-from oe_python_template import Service, __version__
-from oe_python_template.api import app as api
-
-console = Console()
+from . import Service, Utterance, __version__
+from .api import api_v1, api_v2
 
 cli = typer.Typer(name="Command Line Interface of OE Python Template")
+_service = Service()
+_console = Console()
+
+
+@cli.command()
+def health() -> None:
+    """Indicate if service is healthy."""
+    _console.print(_service.healthy())
+
+
+@cli.command()
+def info() -> None:
+    """Print info about service configuration."""
+    _console.print(_service.info())
 
 
 @cli.command()
@@ -29,16 +42,17 @@ def echo(
     ] = False,
 ) -> None:
     """Echo the text."""
+    echo = Service.echo(Utterance(text=text))
     if json:
-        console.print_json(data={"text": text})
+        _console.print_json(data={"text": echo.text})
     else:
-        console.print(text)
+        _console.print(echo.text)
 
 
 @cli.command()
 def hello_world() -> None:
     """Print hello world message and what's in the environment variable THE_VAR."""
-    console.print(Service.get_hello_world())
+    _console.print(_service.get_hello_world())
 
 
 @cli.command()
@@ -48,7 +62,9 @@ def serve(
     watch: Annotated[bool, typer.Option(help="Enable auto-reload")] = True,
 ) -> None:
     """Start the API server."""
-    console.print(f"Starting API server at http://{host}:{port}")
+    _console.print(f"Starting API server at http://{host}:{port}")
+    os.environ["UVICORN_HOST"] = host
+    os.environ["UVICORN_PORT"] = str(port)
     uvicorn.run(
         "oe_python_template.api:app",
         host=host,
@@ -57,6 +73,24 @@ def serve(
     )
 
 
+class APIVersion(StrEnum):
+    """
+    Enum representing the API versions.
+
+    This enum defines the supported API verions:
+    - V1: Output doc for v1 API
+    - V2: Output doc for v2 API
+
+    Usage:
+        version = APIVersion.V1
+        print(f"Using {version} version")
+
+    """
+
+    V1 = "v1"
+    V2 = "v2"
+
+
 class OutputFormat(StrEnum):
     """
     Enum representing the supported output formats.
@@ -76,17 +110,22 @@ class OutputFormat(StrEnum):
 
 @cli.command()
 def openapi(
+    api_version: Annotated[APIVersion, typer.Option(help="API Version", case_sensitive=False)] = APIVersion.V1,
     output_format: Annotated[
         OutputFormat, typer.Option(help="Output format", case_sensitive=False)
     ] = OutputFormat.YAML,
 ) -> None:
     """Dump the OpenAPI specification to stdout (YAML by default)."""
-    schema = api.openapi()
+    match api_version:
+        case APIVersion.V1:
+            schema = api_v1.openapi()
+        case APIVersion.V2:
+            schema = api_v2.openapi()
     match output_format:
         case OutputFormat.JSON:
-            console.print_json(data=schema)
+            _console.print_json(data=schema)
         case OutputFormat.YAML:
-            console.print(yaml.dump(schema, default_flow_style=False), end="")
+            _console.print(yaml.dump(schema, default_flow_style=False), end="")
 
 
 def _apply_cli_settings(cli: typer.Typer, epilog: str) -> None:
